@@ -1,6 +1,6 @@
 from tcsoa.gen.Bom._2008_06.services import StructureManagementService as imp0
 from tcsoa.gen.Bom._2010_09.services import StructureManagementService as imp1
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class StructureManagementService(TcService):
