@@ -1,5 +1,5 @@
 from tcsoa.gen.Configuration._2010_04.services import SmartUiBldrService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class SmartUiBldrService(TcService):
