@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import Fnd0PropagationRule, BusinessObject
+from tcsoa.gen.BusinessObjects import BusinessObject, Fnd0PropagationRule
 from typing import List
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
