@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from tcsoa.gen.DocMgmtAw._2017_06.DocMgmt import PrinterDefinitionResponse
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DocMgmtService(TcService):
