@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import BusinessObject, ItemRevision, Awb0BOMIndexAdminData, RevisionRule, VariantRule
+from tcsoa.gen.BusinessObjects import BusinessObject, VariantRule, Awb0BOMIndexAdminData, RevisionRule, ItemRevision
 from typing import Dict, List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 from datetime import datetime
 
