@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
