@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import BusinessObject, ItemRevision, BOMLine
+from tcsoa.gen.BusinessObjects import BOMLine, BusinessObject, ItemRevision
 from typing import List
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
