@@ -1,13 +1,13 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.AWS2._2016_03.Finder import SearchResponse, GetClassificationPropsResponse, ColumnConfigInput, SearchInput, SaveColumnConfigData
-from tcsoa.gen.Internal.AWS2._2016_03.DataManagement import GetStyleSheetResponse, GetUnprocessedXRTResponse, DSInfo
+from tcsoa.gen.Internal.AWS2._2016_03.Finder import GetClassificationPropsResponse, SearchResponse, SaveColumnConfigData, SearchInput, ColumnConfigInput
+from tcsoa.gen.Internal.AWS2._2016_03.DataManagement import GetUnprocessedXRTResponse, GetStyleSheetResponse, DSInfo
 from tcsoa.gen.Internal.AWS2._2016_03.RequirementsManagement import ExportToApplicationInputData2, ExportToApplicationResponse2
-from tcsoa.gen.Internal.AWS2._2016_03.UiConfig import GetOrResetUIColumnConfigInput, GetVisibleCommandsResponse, GetVisibleCommandsInfo, GetOrResetUIColumnConfigResponse, SaveColumnConfigData
+from tcsoa.gen.Internal.AWS2._2016_03.UiConfig import GetVisibleCommandsResponse, SaveColumnConfigData, GetVisibleCommandsInfo, GetOrResetUIColumnConfigInput, GetOrResetUIColumnConfigResponse
 from tcsoa.gen.Internal.AWS2._2016_04.DataManagement import GetStyleSheetIn
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 from tcsoa.gen.BusinessObjects import WorkspaceObject
 
 
