@@ -1,6 +1,6 @@
 from tcsoa.gen.Internal_OccMgmt._2020_12.services import EffectivityManagementService as imp0
 from tcsoa.gen.Internal_OccMgmt._2020_05.services import ImportExportService as imp1
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class EffectivityManagementService(TcService):
