@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.Search._2020_12.SearchFolder import ReportSearchRecipeResponse, ExportSearchFoldersResponse, ReportSearchRecipeInput, ImportInput, GetSearchFolderAccessorsOutput, CreateOrEditSearchFoldersOutput, ImportSearchFolderResponse, SearchFoldersInput
+from tcsoa.gen.Internal.Search._2020_12.SearchFolder import GetSearchFolderAccessorsOutput, ImportInput, ExportSearchFoldersResponse, ReportSearchRecipeInput, SearchFoldersInput, CreateOrEditSearchFoldersOutput, ReportSearchRecipeResponse, ImportSearchFolderResponse
 from typing import List
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class SearchFolderService(TcService):
