@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_Search._2020_12.services import SearchFolderService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class SearchFolderService(TcService):
