@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_TCXMLImportExport._2020_12.services import BriefcaseService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class BriefcaseService(TcService):
