@@ -1,13 +1,13 @@
 from __future__ import annotations
 
-from tcsoa.gen.Manufacturing._2012_02.DataManagement import DisconnectFromOriginInputData, AssociationResponse, AddAssociationInput, GetAssociatedContextsInputData, AutomaticAllocatePreviewResponse, AssociateAndAllocateInput, ConnectObjectsInputData, AssociateAndAllocateResponse, AllocationMap, ConnectObjectResponse
+from tcsoa.gen.Manufacturing._2012_02.DataManagement import AssociateAndAllocateInput, AssociateAndAllocateResponse, AllocationMap, ConnectObjectResponse, GetAssociatedContextsInputData, AssociationResponse, AutomaticAllocatePreviewResponse, DisconnectFromOriginInputData, AddAssociationInput, ConnectObjectsInputData
 from tcsoa.gen.BusinessObjects import BusinessObject
-from tcsoa.gen.Manufacturing._2012_02.Model import CandidateToolsForToolRequirement, ToolRequirementResponse, ToolRequirementInput, ResolveDataInfo
+from tcsoa.gen.Manufacturing._2012_02.Model import ResolveDataInfo, CandidateToolsForToolRequirement, ToolRequirementResponse, ToolRequirementInput
 from tcsoa.gen.Manufacturing._2012_02.IPAManagement import DeleteFilteredIPAInputInfo, GetFilteredIPATypeResponse
-from tcsoa.gen.Manufacturing._2012_02.Constraints import GetPrecedenceConstraintsResponse, ValidateProcessAreaAssignmentsInputs, GetPrecedenceConstraintPathsResponse, GetPrecedenceConstraintPathsInputs, ValidateConstraintConsistencyResponse, GetPrecedenceConstraintsIn, ValidateProcessAreaAssignmentsResponse, ValidateConstraintConsistencyInputs
+from tcsoa.gen.Manufacturing._2012_02.Constraints import ValidateProcessAreaAssignmentsResponse, ValidateConstraintConsistencyInputs, ValidateConstraintConsistencyResponse, GetPrecedenceConstraintsResponse, GetPrecedenceConstraintPathsInputs, ValidateProcessAreaAssignmentsInputs, GetPrecedenceConstraintsIn, GetPrecedenceConstraintPathsResponse
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class DataManagementService(TcService):
