@@ -1,5 +1,5 @@
 from tcsoa.gen.Qualification._2014_06.services import QualificationManagementService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class QualificationManagementService(TcService):
