@@ -3,7 +3,7 @@ from tcsoa.gen.Rdv._2012_09.services import ContextManagementService as imp1
 from tcsoa.gen.Rdv._2010_09.services import ContextManagementService as imp2
 from tcsoa.gen.Rdv._2009_04.services import ContextManagementService as imp3
 from tcsoa.gen.Rdv._2013_05.services import ContextManagementService as imp4
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ContextManagementService(TcService):
