@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import BOMWindow, PSBOMView, PublishLink, BOMLine
+from tcsoa.gen.BusinessObjects import BOMLine, BOMWindow, PublishLink, PSBOMView
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
