@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import ReleaseStatus, Item, ItemRevision, BOMLine
+from tcsoa.gen.BusinessObjects import BOMLine, Item, ReleaseStatus, ItemRevision
 from typing import List
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 from datetime import datetime
 
