@@ -16,7 +16,7 @@ class EPMAttachmentType(enum.IntEnum):
     EPM_user_attachment = 1000
 
 
-class EPMAttachmentType2(enum.StrEnum):
+class EPMAttachmentType2(enum.Enum):
     """ Necessary when using WorkflowService.createWorkflow or WorkflowService#createRemoteWorkflowAsync """
 
     EPM_ATT_TARGET = "target"
@@ -37,7 +37,7 @@ class EPMConditionTask(enum.IntEnum):
     EPM_RESULT_UNSET = 2
 
 
-class RelationTypes(enum.StrEnum):
+class RelationTypes(enum.Enum):
     EPM_TEMPLATE_BASED_ON_RELATION_TYPE = "EPM_template_based_on"
     EPM_SIGNOFF_PROFILE_RELATION_TYPE = "EPM_signoff_profile"
     SUBSCRIBED_REMOTEINBOXES_RELATION_TYPE = "subscribed_remoteinboxes"
